Merge Lists — WARIO 1.0.0 documentation

# Merge Lists

## Description

Allows for 4 lists to be merged together. Connected inputs are verification checked at runtime so the lists can be connected to any combination of inputs.

## Input

Name | Type | Description
--- | --- | ---
List 1 | list | First list
List 2 | list | Second list
List 3 | list | Third list
List 4 | list | Fourth List

## Output

Name | Type | Description
--- | --- | ---
Merged List | list | Combined list from inputs

## Settings

“Delete Duplicates” toggle allows the user to select if duplicate items from the combined lists should be deleted